#!/bin/sh
<% if @service_token -%>
export OS_SERVICE_TOKEN='<%= @service_token.gsub(/'/){ %q(\') } %>'
export OS_SERVICE_ENDPOINT='<%= @service_endpoint %>'
<% end -%>
export OS_NO_CACHE='<%= @use_no_cache %>'
<% if @project_name -%>
export OS_PROJECT_NAME='<%= @project_name %>'
<% end -%>
export OS_USERNAME='<%= @username %>'
export OS_PASSWORD='<%= @password.gsub(/'/){ %q(\') } %>'
export OS_AUTH_URL='<%= @auth_url %>'
export OS_AUTH_STRATEGY='<%= @auth_strategy %>'
export OS_REGION_NAME='<%= @region_name %>'
<% if @project_domain_name -%>
export OS_PROJECT_DOMAIN_NAME='<%= @project_domain_name %>'
<% end -%>
<% if @user_domain_name -%>
export OS_USER_DOMAIN_NAME='<%= @user_domain_name %>'
<% end -%>
<% if @auth_type -%>
export OS_AUTH_TYPE='<%= @auth_type %>'
<% end -%>
export OS_INTERFACE='<%= @os_interface %>'
export OS_ENDPOINT_TYPE='<%= @os_endpoint_type %>'
export CINDER_ENDPOINT_TYPE='<%= @cinder_endpoint_type %>'
export GLANCE_ENDPOINT_TYPE='<%= @glance_endpoint_type %>'
export KEYSTONE_ENDPOINT_TYPE='<%= @keystone_endpoint_type %>'
export NOVA_ENDPOINT_TYPE='<%= @nova_endpoint_type %>'
export NEUTRON_ENDPOINT_TYPE='<%= @neutron_endpoint_type %>'
<% if @compute_api_version -%>
export OS_COMPUTE_API_VERSION='<%= @compute_api_version %>'
<% end -%>
<% if @network_api_version -%>
export OS_NETWORK_API_VERSION='<%= @network_api_version %>'
<% end -%>
<% if @image_api_version -%>
export OS_IMAGE_API_VERSION='<%= @image_api_version %>'
<% end -%>
<% if @volume_api_version -%>
export OS_VOLUME_API_VERSION='<%= @volume_api_version %>'
<% end -%>
<% if @identity_api_version -%>
export OS_IDENTITY_API_VERSION='<%= @identity_api_version %>'
<% end -%>
<% if @object_api_version -%>
export OS_OBJECT_API_VERSION='<%= @object_api_version %>'
<% end -%>
